AnnotationIssue class

A single annotation validation problem in a reference file.

Annotations
  • @immutable

Constructors

AnnotationIssue({required String filePath, required int line, required String message, int? column})
Creates an AnnotationIssue.
const

Properties

column → int?
Optional one-based column number.
final
filePath → String
Path to the file relative to the reference root, or absolute.
final
hashCode → int
The hash code for this object.
no setterinherited
line → int
One-based line number.
final
message → String
Human-readable description of the problem.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited