ClayConfig class
Parsed clay.yaml configuration.
- Mixed-in types
- Annotations
-
- @immutable
- @MappableClass.new()
Constructors
-
ClayConfig({String reference = ClayConfig.defaultReferencePath, ClayEnvironment? environment, List<
String> ignore = const [], List<Replacement> replacements = const [], List<LineDeletion> lineDeletions = const [], String? target}) - Creates a ClayConfig.
Properties
-
copyWith
→ ClayConfigCopyWith<
ClayConfig, ClayConfig, ClayConfig> -
no setterinherited
- environment → ClayEnvironment
-
Tool version constraints for this project.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
ignore
→ List<
String> -
Gitignore-style glob patterns excluded from template output.
final
-
lineDeletions
→ List<
LineDeletion> -
Line ranges removed from specific target files.
final
- reference → String
-
Path to the reference project root.
final
-
replacements
→ List<
Replacement> -
Regex replacements applied to file paths and contents.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- target → String
-
Path to the template output root.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
inherited
-
toMap(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- defaultTargetPath → String
-
Default ClayConfig.target when omitted.
final
Constants
- defaultReferencePath → const String
- Default ClayConfig.reference when omitted.
-
fromMap
→ const ClayConfig Function(Map<
String, dynamic> map) - Creates a ClayConfig from a config map.