ClayConfigMapper class

Properties

fields → MappableFields<ClayConfig>
The set of fields this interface defines.
final
hashCode int
The hash code for this object.
no setterinherited
hook → MappingHook?
The optional mapping hook defined for this interface.
no setterinherited
id String
A unique id for this type, defaults to the name of the type.
final
ignoreNull bool
Whether to ignore null values when encoding the fields of this interface.
no setterinherited
instantiate Function
The instantiate method to create a new instance of this interface.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shallowEncoding bool
Whether to encode nested objects or just one level deep.
finalinherited
superHook → MappingHook?
The optional mapping hook defined for the superclass of this class.
no setterinherited
type Type
A getter for the type of this mapper.
no setterinherited
typeFactory Function
A type factory is what makes generic types work.
no setterinherited

Methods

addSubMapper(SubClassMapperBase<ClayConfig> mapper) → void
Adds a subclass mapper to this mapper.
inherited
decode(Object? value, DecodingContext context) ClayConfig
inherited
decodeJson<V>(String json) → V
inherited
decodeMap<V>(Map<String, dynamic> map) → V
inherited
decoder(Object? value, DecodingContext context) ClayConfig
The mapping method to decode value to an instance of this mappers type.
inherited
decodeValue<V>(Object? value, [DecodingOptions? options, MapperContainer? container]) → V
inherited
encode(ClayConfig value, EncodingContext context) Object?
inherited
encodeJson<V>(V object, [EncodingOptions? options]) String
inherited
encodeMap<V>(V object, [EncodingOptions? options]) Map<String, dynamic>
inherited
encoder(ClayConfig value, EncodingContext context) Object?
The mapping method to encode value to a serializable value.
inherited
encodeValue<V>(V value, [EncodingOptions? options, MapperContainer? container]) Object?
inherited
equals(ClayConfig value, ClayConfig other, MappingContext context) bool
The mapping method to compare value and other for equality.
inherited
equalsValue(ClayConfig value, Object? other, [MapperContainer? container]) bool
inherited
hash(ClayConfig value, MappingContext context) int
The mapping method to calculate the hash of value.
inherited
hashValue(ClayConfig value, [MapperContainer? container]) int
inherited
includeTypeId<V>(dynamic v) bool
inherited
inherit(DecodingContext context) → DecodingContext
This will inherit the decoding context when giving over decoding to a subclass.
inherited
isFor(dynamic v) bool
inherited
isForType(Type type) bool
inherited
isValueEqual(ClayConfig value, Object? other, [MapperContainer? container]) bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
stringify(ClayConfig value, MappingContext context) String
The mapping method to get the string representation of value.
inherited
stringifyValue(ClayConfig value, [MapperContainer? container]) String
inherited
subOrSelfFor(dynamic value) → MapperBase<Object>?
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

ensureInitialized() ClayConfigMapper
fromJson(String json) ClayConfig
fromMap(Map<String, dynamic> map) ClayConfig