LineRange class

An inclusive, zero-based line range within a target file.

Mixed-in types
Annotations
  • @immutable
  • @MappableClass.new()

Constructors

LineRange({required int start, required int end})
Creates a LineRange.
const

Properties

copyWith LineRangeCopyWith<LineRange, LineRange, LineRange>
no setterinherited
end int
The end of the range (inclusive and zero-based).
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start int
The beginning of the range (inclusive and zero-based).
final

Methods

contains(int lineNumber) bool
Whether lineNumber falls within this range.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
inherited
toMap() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fromJson → const LineRange Function(Map<String, dynamic> map)
Creates a LineRange from a JSON map.