Replacement class

A regex replacement applied to file paths and contents.

Mixed-in types
Annotations
  • @immutable
  • @MappableClass.new()

Constructors

Replacement({required RegExp from, required String to})
Creates a Replacement.
const

Properties

copyWith ReplacementCopyWith<Replacement, Replacement, Replacement>
no setterinherited
from RegExp
The pattern to match.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
to String
The replacement string; supports ${n} capture-group interpolation.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
inherited
toMap() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fromJson → const Replacement Function(Map<String, dynamic> map)
Creates a Replacement from a JSON map.