ClayConfigNotFoundException class

Thrown when clay.yaml cannot be discovered.

Implemented types

Constructors

ClayConfigNotFoundException({required String message, required List<String> searchedPaths})
Creates a ClayConfigNotFoundException.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String
Human-readable error description.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchedPaths → List<String>
Candidate paths checked during discovery.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited