ClayIncompatibleException class

Thrown when the running Clay version does not satisfy environment.clay.

Implemented types

Constructors

ClayIncompatibleException({required String currentVersion, required String requiredConstraint})
Creates a ClayIncompatibleException.
const

Properties

currentVersion → String
The installed Clay library version.
final
hashCode → int
The hash code for this object.
no setterinherited
requiredConstraint → String
The semver constraint declared in environment.clay.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited