ClayConfigCopyWith<$R, $In extends ClayConfig, $Out> class
abstract
- Available extensions
Constructors
Properties
-
$asClayConfig
→ ClayConfigCopyWith<
$R, ClayConfig, $Out> -
Available on ObjectCopyWith<
$R, ClayConfig, $Out> , provided by the ClayConfigValueCopy extensionno setter -
environment
→ ClayEnvironmentCopyWith<
$R, ClayEnvironment, ClayEnvironment> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
ignore
→ ListCopyWith<
$R, String, ObjectCopyWith< $R, String, String> > -
no setter
-
lineDeletions
→ ListCopyWith<
$R, LineDeletion, LineDeletionCopyWith< $R, LineDeletion, LineDeletion> > -
no setter
-
replacements
→ ListCopyWith<
$R, Replacement, ReplacementCopyWith< $R, Replacement, Replacement> > -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$chain<
$R2, $Out2> (Then< $Out2, $R2> t) → ClayConfigCopyWith<$R2, $In, $Out2> -
$delta(
Map< String, dynamic> delta) → $R -
inherited
-
$merge(
$In value) → $R -
inherited
-
$update(
$Out transform($In)) → $R -
inherited
-
call(
{String? reference, ClayEnvironment? environment, List< String> ? ignore, List<Replacement> ? replacements, List<LineDeletion> ? lineDeletions, String? target}) → $R -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited