ClayEnvironment class
Semver environment constraints declared in clay.yaml.
- Mixed-in types
- Annotations
-
- @immutable
- @MappableClass.new()
Constructors
- ClayEnvironment({VersionConstraint? clay})
- Creates a ClayEnvironment.
Properties
- clay → VersionConstraint
-
Semver constraint for the Clay CLI/library version required by this project.
final
-
copyWith
→ ClayEnvironmentCopyWith<
ClayEnvironment, ClayEnvironment, ClayEnvironment> -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
inherited
-
toMap(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- defaultClayConstraint → VersionConstraint
-
Default ClayEnvironment.clay when omitted.
final
Constants
-
fromMap
→ const ClayEnvironment Function(Map<
String, dynamic> map) - Creates a ClayEnvironment from a config map.