LineDeletion class

Line ranges to drop from a specific target file.

Mixed-in types
Annotations
  • @immutable
  • @MappableClass.new()

Constructors

LineDeletion({required String filePath, required List<LineRange> ranges})
Creates a LineDeletion.
const

Properties

copyWith LineDeletionCopyWith<LineDeletion, LineDeletion, LineDeletion>
no setterinherited
filePath String
Path to the target file, relative to the target directory root.
final
hashCode int
The hash code for this object.
no setterinherited
ranges List<LineRange>
Ranges of lines to remove from filePath.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
inherited
toMap() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fromJson → const LineDeletion Function(Map<String, dynamic> map)
Creates a LineDeletion from a JSON map.