DiscoveredClayConfig class

Result of locating clay.yaml and its project root.

Constructors

DiscoveredClayConfig({required String configPath, required String projectRoot})
Creates a DiscoveredClayConfig.
const

Properties

configPath String
Absolute path to the resolved clay.yaml file.
final
hashCode int
The hash code for this object.
no setterinherited
projectRoot String
Absolute path to the project root (parent of configPath).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited